import { IProductSupplyOptions } from "./marketablestock/product-supply";
import { ICumulusCookies, ILoginCookies } from "./interfaces/cookies";
import { ICumulusReceiptOptions, ICumulusReceiptsOptions } from "./cumulus/receipts";
import { ICumulusReceiptResponse, ICumulusReceiptsResponse } from "./interfaces/receipts";
import { IProductCardsOptions } from "./product-display/product-cards";
import { IProductSearchBody, IProductSearchOptions } from "./onesearch-oc-seaapi/product-search";
import { ICategoryListBody, ICategoryListOptions } from "./onesearch-oc-seaapi/category";
import { ISearchStoresOptions } from "./stores/search-stores";
export declare class MigrosAPI {
    private _leShopToken;
    get leShopToken(): string;
    set leShopToken(value: string);
    private _cumulusToken;
    get cumulusToken(): string;
    set cumulusToken(value: string);
    private _loginCookies;
    get loginCookies(): ILoginCookies | undefined;
    set loginCookies(value: ILoginCookies | undefined);
    private _cumulusCookies;
    get cumulusCookies(): ICumulusCookies | undefined;
    set cumulusCookies(value: ICumulusCookies | undefined);
    static products: {
        productStock: {
            getProductSupply: typeof import("./marketablestock/product-supply").getProductSupply;
        };
        productDisplay: {
            getProductCards: typeof import("./product-display/product-cards").getProductCards;
            getProductDetails: typeof import("./product-display/product-detail").getProductDetail;
        };
        productSearch: {
            searchProduct: typeof import("./onesearch-oc-seaapi/product-search").postProductSearch;
            listCategories: typeof import("./onesearch-oc-seaapi/category").categoryList;
        };
    };
    static stores: {
        searchStores: typeof import("./stores/search-stores").searchStores;
    };
    static account: {
        oauth2: {
            getUserInfo: typeof import("./oauth2/userinfo").getUserInfo;
            getGuestToken: typeof import("./oauth2/guest-token").getGuestToken;
        };
        security: {
            getOptions: typeof import("./security/options").getOptions;
            getPaymentDevices: typeof import("./security/devices").getPaymentDevices;
        };
        cumulus: {
            getCumulusSession: typeof import("./cumulus/session").getCumulusSession;
            getCumulusStats: typeof import("./cumulus/stats").getCumulusStats;
            getCumulusReceipt: typeof import("./cumulus/receipts").getCumulusReceipt;
            getCumulusReceiptFromUrl: typeof import("./cumulus/receipts").getCumulusReceiptFromUrl;
            getCumulusReceipts: typeof import("./cumulus/receipts").getCumulusReceipts;
            getCumulusPrincipal: typeof import("./cumulus/principal").getCumulusPrincipal;
            getCumulusServicesSmall: typeof import("./cumulus/services").getCumulusServicesSmall;
            getCumulusPaymentSites: typeof import("./cumulus/payment-sites").getCumulusPaymentSites;
            getCumulusCreditCard: typeof import("./cumulus/credit-card").getCumulusCreditCard;
            getCumulusHousehold: typeof import("./cumulus/household").getCumulusHousehold;
            getCumulusInvoice: typeof import("./cumulus/invoice").getCumulusInvoice;
        };
    };
    static migusto: {
        recipeSearch: typeof import("./migusto/recipe-search").postRecipeSearch;
        recipeProducts: typeof import("./migusto/recipe-products").getRecipeProducts;
        recipeDetails: typeof import("./migusto/recipe-details").getRecipeDetails;
    };
    stores: {
        searchStores: (searchStoresOptions: ISearchStoresOptions, token?: string | undefined) => Promise<any>;
    };
    products: {
        productStock: {
            getProductSupply: (productSupplyOptions: IProductSupplyOptions, token?: string | undefined) => Promise<any>;
        };
        productDisplay: {
            getProductCards: (productCardOptions: IProductCardsOptions, token?: string | undefined) => Promise<any>;
            getProductDetails: (productSupplyOptions: IProductSupplyOptions, token?: string | undefined) => Promise<any>;
        };
        productSearch: {
            categoryList: (categoryListBody: ICategoryListBody, categoryListOptions?: ICategoryListOptions, token?: string | undefined) => Promise<any>;
            searchProduct: (productSearchBody: IProductSearchBody, productSearchOptions?: IProductSearchOptions, token?: string | undefined) => Promise<any>;
        };
    };
    account: {
        oauth2: {
            loginGuestToken: () => Promise<any>;
            getUserInfo: (token?: string | undefined) => Promise<any>;
        };
        security: {
            getOptions: (cookies?: ILoginCookies | undefined) => Promise<any>;
            getPaymentDevices: (cookies?: ILoginCookies | undefined) => Promise<any>;
        };
        cumulus: {
            getCumulusStats: (cookies?: ILoginCookies | undefined) => Promise<any>;
            getCumulusReceipt: (cumulusReceiptOptions: ICumulusReceiptOptions, cookies?: ICumulusCookies | undefined, htmlOnly?: boolean) => Promise<ICumulusReceiptResponse | string>;
            getCumulusReceiptFromUrl: (url: string, cookies?: ICumulusCookies | undefined, htmlOnly?: boolean) => Promise<ICumulusReceiptResponse | string>;
            getCumulusReceipts: (cumulusReceiptsOptions: ICumulusReceiptsOptions, cookies?: ICumulusCookies | undefined) => Promise<ICumulusReceiptsResponse>;
            getCumulusPrincipal: (cookies?: ILoginCookies | undefined) => Promise<any>;
            getCumulusServicesSmall: (cookies?: ILoginCookies | undefined) => Promise<any>;
            getCumulusPaymentSites: (cookies?: ILoginCookies | undefined) => Promise<any>;
            getCumulusCreditCard: (cookies?: ILoginCookies | undefined) => Promise<any>;
            getCumulusHousehold: (cookies?: ILoginCookies | undefined) => Promise<any>;
            getCumulusInvoice: (cookies?: ILoginCookies | undefined) => Promise<any>;
        };
    };
}
